@@ -4,6 +4,8 @@ package File::PlainPath;
 
 # ABSTRACT: Construct portable filesystem paths in a simple way
 
+our $VERSION = '0.030'; # VERSION
+
 use File::Spec;
 
 
@@ -11,15 +13,39 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(path to_path);
 
-# Mapping between package names and regular expressions that match directory
-# separators
-my %separator_re;
+sub import
+{
+    my $class  = shift;
+    my %opts   = ();
+    my @export = ();
+    while (@_) {
+        my $arg = shift;
+        if ($arg =~ m{^ [-] (.+) $}x)
+        {
+            $opts{$1} = shift;
+            next;
+        }
+        push @export, $arg;
+    }
+    
+    if (exists $opts{'separator'}) {
+        $^H{+__PACKAGE__} = $opts{'separator'};
+    }
+    
+    @_ = ($class, @export);
+    goto \&Exporter::import;
+}
 
 
-sub path {
+sub path {    
+    my @caller       = caller(0);
+    my $separator    = exists $caller[10]{+__PACKAGE__} ?
+        $caller[10]{+__PACKAGE__} : '/';
+    my $separator_re = qr{ \Q$separator\E }x;
+
     my @paths = @_;
-    my @path_components = map { split($separator_re{caller()} ||= '/', $_) }
-        @paths;
+    my @path_components = map { split($separator_re, $_) } @paths;
+
     return File::Spec->catfile(@path_components);
 }
 
@@ -27,24 +53,21 @@ sub path {
 *to_path = *path;
 
 
-sub set_separator {
-    my $separator = quotemeta(shift);
-    $separator_re{caller()} = qr{$separator};
-}
-
-
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 File::PlainPath - Construct portable filesystem paths in a simple way
 
 =head1 VERSION
 
-version 0.02
+version 0.030
 
 =head1 SYNOPSIS
 
@@ -54,7 +77,7 @@ version 0.02
     my $path = path 'dir/subdir/file.txt';
     
     # Set backslash as directory separator
-    File::PlainPath::set_separator('\\');   
+    use File::PlainPath -separator => '\\';   
     my $other_path = path 'dir\\other_dir\\other_file.txt';
 
 =head1 DESCRIPTION
@@ -71,9 +94,11 @@ with a simpler notation:
 The default directory separator used in paths is the forward slash (C</>), but
 any other character can be designated as the separator:
 
-    File::PlainPath::set_separator(':');
+    use File::PlainPath -separator => ':';
     my $path = path 'dir:subdir:file.txt';
 
+This is lexically scoped.
+
 =head1 FUNCTIONS
 
 =head2 path
@@ -99,14 +124,6 @@ Example:
     
     my $path = to_path 'dir/file.txt';
 
-=head2 set_separator
-
-Sets the character to be used as directory separator.
-
-Example:
-
-    File::PlainPath::set_separator(':');
-
 =head1 SEE ALSO
 
 =over 4
@@ -115,10 +132,47 @@ Example:
 
 =back
 
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/odyniec/File-PlainPath/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software.  The code repository is available for
+public review and contribution under the terms of the license.
+
+L<https://github.com/odyniec/File-PlainPath>
+
+  git clone https://github.com/odyniec/File-PlainPath.git
+
 =head1 AUTHOR
 
 Michal Wojciechowski <odyniec@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Michal Wojciechowski <odyniec@odyniec.net>
+
+=item *
+
+Michał Wojciechowski <odyniec@odyniec.eu.org>
+
+=item *
+
+Toby Inkster <tobyink@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by Michal Wojciechowski.
@@ -127,4 +181,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
